@@ -7,7 +7,7 @@ require "minitest/parallel"
 # :include: README.rdoc
 
 module Minitest
-  VERSION = "5.8.4" # :nodoc:
+  VERSION = "5.9.0" # :nodoc:
   ENCS = "".respond_to? :encoding # :nodoc:
 
   @@installed_at_exit ||= false
@@ -39,6 +39,12 @@ module Minitest
 
   mc.send :attr_accessor, :extensions
 
+  ##
+  # The signal to use for dumping information to STDERR. Defaults to "INFO".
+
+  mc.send :attr_accessor, :info_signal
+  self.info_signal = "INFO"
+
   ##
   # Registers Minitest to run at process exit
 
@@ -181,6 +187,10 @@ module Minitest
         options[:filter] = a
       end
 
+      opts.on "-e", "--exclude PATTERN", "Exclude /regexp/ or string from run." do |a|
+        options[:exclude] = a
+      end
+
       unless extensions.empty?
         opts.separator ""
         opts.separator "Known extensions: #{extensions.join(", ")}"
@@ -286,6 +296,13 @@ module Minitest
         filter === m || filter === "#{self}##{m}"
       }
 
+      exclude = options[:exclude]
+      exclude = Regexp.new $1 if exclude =~ %r%/(.*)/%
+
+      filtered_methods.delete_if { |m|
+        exclude === m || exclude === "#{self}##{m}"
+      }
+
       return if filtered_methods.empty?
 
       with_info_handler reporter do
@@ -315,7 +332,7 @@ module Minitest
         end
       end
 
-      on_signal "INFO", handler, &block
+      on_signal ::Minitest.info_signal, handler, &block
     end
 
     SIGNALS = Signal.list # :nodoc:
@@ -612,6 +629,10 @@ module Minitest
       self.reporters = reporters
     end
 
+    def io # :nodoc:
+      reporters.first.io
+    end
+
     ##
     # Add another reporter to the mix.
 
