@@ -1,3 +1,5 @@
+# encoding: UTF-8
+
 require "rbconfig"
 require "tempfile"
 require "stringio"
@@ -104,7 +106,15 @@ module Minitest
 
     def mu_pp obj
       s = obj.inspect
-      s = s.encode Encoding.default_external if defined? Encoding
+
+      if defined? Encoding then
+        s = s.encode Encoding.default_external
+
+        if String === obj && obj.encoding != Encoding.default_external then
+          s = "# encoding: #{obj.encoding}\n#{s}"
+        end
+      end
+
       s
     end
 
@@ -124,7 +134,7 @@ module Minitest
     def assert test, msg = nil
       self.assertions += 1
       unless test then
-        msg ||= "Failed assertion, no message given."
+        msg ||= "Expected #{mu_pp test} to be truthy."
         msg = msg.call if Proc === msg
         raise Minitest::Assertion, msg
       end
@@ -152,7 +162,8 @@ module Minitest
     #
     # If there is no visible difference but the assertion fails, you
     # should suspect that your #== is buggy, or your inspect output is
-    # missing crucial details.
+    # missing crucial details.  For nicer structural diffing, set
+    # Minitest::Test.make_my_diffs_pretty!
     #
     # For floats use assert_in_delta.
     #
@@ -252,6 +263,8 @@ module Minitest
     # "" if you require it to be silent. Pass in a regexp if you want
     # to pattern match.
     #
+    #   assert_output(/hey/) { method_with_output }
+    #
     # NOTE: this uses #capture_io, not #capture_subprocess_io.
     #
     # See also: #assert_silent
@@ -501,7 +514,7 @@ module Minitest
     # Fails if +test+ is truthy.
 
     def refute test, msg = nil
-      msg ||= "Failed refutation, no message given"
+      msg ||= message { "Expected #{mu_pp(test)} to not be truthy" }
       not assert !test, msg
     end
 
